@@ -2,17 +2,15 @@
 #include <qpdf/Pl_StdioFile.hh>
 #include <qpdf/QUtil.hh>
 
-#include <stdio.h>
-#include <string.h>
+#include <cstdio>
+#include <cstdlib>
 #include <iostream>
-#include <stdlib.h>
 
-int main(int argc, char* argv[])
+int
+main(int argc, char* argv[])
 {
-    if (argc != 3)
-    {
-        std::cerr << "Usage: dct_uncompress infile outfile"
-                  << std::endl;
+    if (argc != 3) {
+        std::cerr << "Usage: dct_uncompress infile outfile" << std::endl;
         exit(2);
     }
 
@@ -25,15 +23,11 @@ int main(int argc, char* argv[])
     unsigned char buf[100];
     bool done = false;
     Pl_DCT dct("dct", &out);
-    while (! done)
-    {
+    while (!done) {
         size_t len = fread(buf, 1, sizeof(buf), infile);
-        if (len <= 0)
-        {
+        if (len <= 0) {
             done = true;
-        }
-        else
-        {
+        } else {
             dct.write(buf, len);
         }
     }
